var searchData=
[
  ['the_20db_2dlib_20api',['The db-lib API',['../a00517.html',1,'']]],
  ['tag_5fdbproc_5frowbuf',['tag_DBPROC_ROWBUF',['../a00873.html',1,'']]],
  ['tagss_5ftime2_5fstruct',['tagSS_TIME2_STRUCT',['../a01221.html',1,'']]],
  ['tagss_5ftimestampoffset_5fstruct',['tagSS_TIMESTAMPOFFSET_STRUCT',['../a01225.html',1,'']]],
  ['tds',['tds',['../a00993.html#ad357e33164f46fce2bc70267d71a1959',1,'_hstmt']]],
  ['tds_2eh',['tds.h',['../a00434.html',1,'']]],
  ['tds5_5ffix_5fdot_5fquery',['tds5_fix_dot_query',['../a00533.html#ga3a5d1771cacc947521c4077551f0d3a4',1,'query.c']]],
  ['tds5_5fprocess_5fdyn_5fresult2',['tds5_process_dyn_result2',['../a00536.html#gae688b515631141acfbc41bbb91c8b921',1,'token.c']]],
  ['tds5_5fprocess_5foptioncmd',['tds5_process_optioncmd',['../a00536.html#gaa6a7e5aeb10a1322911c47be9c43e2d2',1,'token.c']]],
  ['tds5_5fprocess_5fresult',['tds5_process_result',['../a00536.html#ga547b2f48659f77a69aa802d861ac827d',1,'token.c']]],
  ['tds5_5fprocess_5fresult2',['tds5_process_result2',['../a00536.html#gabe2bdd5a41ce067cb31aef18ff81cb1c',1,'token.c']]],
  ['tds71_5fcollation',['TDS71_COLLATION',['../a01033.html',1,'']]],
  ['tds71_5fread_5ftable_5fnames',['tds71_read_table_names',['../a00536.html#ga7482b5730d880fcedbe9fcd609a550ce',1,'token.c']]],
  ['tds71_5fsubmit_5fprepexec',['tds71_submit_prepexec',['../a00533.html#ga08877c101704bebe4fa57e0849dc272d',1,'tds71_submit_prepexec(TDSSOCKET *tds, const char *query, const char *id, TDSDYNAMIC **dyn_out, TDSPARAMINFO *params):&#160;query.c'],['../a00533.html#ga08877c101704bebe4fa57e0849dc272d',1,'tds71_submit_prepexec(TDSSOCKET *tds, const char *query, const char *id, TDSDYNAMIC **dyn_out, TDSPARAMINFO *params):&#160;query.c']]],
  ['tds72_5fsmp_5fheader',['TDS72_SMP_HEADER',['../a01037.html',1,'']]],
  ['tds7_5fbcp_5fsend_5fcolmetadata',['tds7_bcp_send_colmetadata',['../a00248.html#a4daaa551e54dbd978650e2eef89e09ff',1,'bulk.c']]],
  ['tds7_5fbuild_5fbulk_5finsert_5fstmt',['tds7_build_bulk_insert_stmt',['../a00248.html#a3118c7232bc9c3e47f8ba872bb39e967',1,'bulk.c']]],
  ['tds7_5fbuild_5fparam_5fdef_5ffrom_5fparams',['tds7_build_param_def_from_params',['../a00533.html#gac8d5497c2d1b9fadb724111660bd03bd',1,'query.c']]],
  ['tds7_5fbuild_5fparam_5fdef_5ffrom_5fquery',['tds7_build_param_def_from_query',['../a00533.html#gab775332d378c7fe083750d624441b303',1,'query.c']]],
  ['tds7_5fget_5fdata_5finfo',['tds7_get_data_info',['../a00536.html#ga07cee55fd522cca16fb59b7a8f0b1376',1,'token.c']]],
  ['tds7_5fget_5finstance_5fport',['tds7_get_instance_port',['../a00534.html#gac23c12ccb3e8599f10f305e993e216f6',1,'tds7_get_instance_port(struct addrinfo *addr, const char *instance):&#160;net.c'],['../a00534.html#gac23c12ccb3e8599f10f305e993e216f6',1,'tds7_get_instance_port(struct addrinfo *addr, const char *instance):&#160;net.c']]],
  ['tds7_5fget_5finstance_5fports',['tds7_get_instance_ports',['../a00534.html#ga954dcc3b0332fa9448d9edf59c0fe439',1,'tds7_get_instance_ports(FILE *output, struct addrinfo *addr):&#160;net.c'],['../a00534.html#ga954dcc3b0332fa9448d9edf59c0fe439',1,'tds7_get_instance_ports(FILE *output, struct addrinfo *addr):&#160;net.c']]],
  ['tds7_5fprocess_5fcompute_5fresult',['tds7_process_compute_result',['../a00536.html#ga6728e344caa20aea1def85f58dea138b',1,'token.c']]],
  ['tds7_5fprocess_5fresult',['tds7_process_result',['../a00536.html#gaca56fc22d65a24a96d1bef310ade73aa',1,'token.c']]],
  ['tds7_5fput_5fparams_5fdefinition',['tds7_put_params_definition',['../a00533.html#ga0f0b6bf447e9672e3b1ea8453ddeb113',1,'query.c']]],
  ['tds7_5fput_5fquery_5fparams',['tds7_put_query_params',['../a00533.html#ga6e42b4a1d1d3898229ea2fe4afc2ecec',1,'query.c']]],
  ['tds7_5fsend_5fexecute',['tds7_send_execute',['../a00533.html#gab71e2dc686eafe926dbebbce00d27dc4',1,'query.c']]],
  ['tds_5faddrinfo',['tds_addrinfo',['../a01233.html',1,'']]],
  ['tds_5falign_5fstruct',['tds_align_struct',['../a01089.html',1,'']]],
  ['tds_5falloc_5fcompute_5fresult',['tds_alloc_compute_result',['../a00532.html#gae042c280bdf5ecdd530a6e5cc2cf83f5',1,'mem.c']]],
  ['tds_5falloc_5fdynamic',['tds_alloc_dynamic',['../a00532.html#ga69559de43b47f4a9e2eecc7a56527444',1,'tds_alloc_dynamic(TDSCONNECTION *conn, const char *id):&#160;mem.c'],['../a00532.html#ga69559de43b47f4a9e2eecc7a56527444',1,'tds_alloc_dynamic(TDSCONNECTION *conn, const char *id):&#160;mem.c']]],
  ['tds_5falloc_5fget_5fstring',['tds_alloc_get_string',['../a00536.html#gafb26aba5d935e40b87b95e21a5185848',1,'token.c']]],
  ['tds_5falloc_5fparam_5fdata',['tds_alloc_param_data',['../a00532.html#ga282d67682d293810625d87d566443c2d',1,'tds_alloc_param_data(TDSCOLUMN *curparam):&#160;mem.c'],['../a00532.html#ga282d67682d293810625d87d566443c2d',1,'tds_alloc_param_data(TDSCOLUMN *curparam):&#160;mem.c']]],
  ['tds_5falloc_5fparam_5fresult',['tds_alloc_param_result',['../a00532.html#ga314c65c067570dc1ef3e58bbfc4eb763',1,'tds_alloc_param_result(TDSPARAMINFO *old_param):&#160;mem.c'],['../a00532.html#ga314c65c067570dc1ef3e58bbfc4eb763',1,'tds_alloc_param_result(TDSPARAMINFO *old_param):&#160;mem.c']]],
  ['tds_5falloc_5frow',['tds_alloc_row',['../a00532.html#ga1224fb9277112dc2ce12531d2b73b145',1,'tds_alloc_row(TDSRESULTINFO *res_info):&#160;mem.c'],['../a00532.html#ga1224fb9277112dc2ce12531d2b73b145',1,'tds_alloc_row(TDSRESULTINFO *res_info):&#160;mem.c']]],
  ['tds_5fanswer',['tds_answer',['../a00697.html',1,'']]],
  ['tds_5fanswer_5fchallenge',['tds_answer_challenge',['../a00528.html#ga4c76be38f4758db45be58f9de8ccdef0',1,'challenge.c']]],
  ['tds_5fascii_5fto_5fucs2',['tds_ascii_to_ucs2',['../a00533.html#gad05fc65e1d505c68d14c82b99a00e4eb',1,'query.c']]],
  ['tds_5fauthentication',['tds_authentication',['../a01177.html',1,'']]],
  ['tds_5fbcp_5fadd_5ffixed_5fcolumns',['tds_bcp_add_fixed_columns',['../a00248.html#a6d1e3ee3ba4ddeac7d5c9b5e30b185f1',1,'bulk.c']]],
  ['tds_5fbcp_5fadd_5fvariable_5fcolumns',['tds_bcp_add_variable_columns',['../a00248.html#a0184a0b53bd92aeca39b136542238dd4',1,'bulk.c']]],
  ['tds_5fbcp_5fdirections',['tds_bcp_directions',['../a00434.html#ad5c5c8cb776334af4b0ebf7a0d740cb2',1,'tds.h']]],
  ['tds_5fbcp_5fdone',['tds_bcp_done',['../a00248.html#ade7df2db455b61edc83819ad60edb339',1,'tds_bcp_done(TDSSOCKET *tds, int *rows_copied):&#160;bulk.c'],['../a00434.html#ade7df2db455b61edc83819ad60edb339',1,'tds_bcp_done(TDSSOCKET *tds, int *rows_copied):&#160;bulk.c']]],
  ['tds_5fbcp_5ffread',['tds_bcp_fread',['../a00248.html#a86ac92bd8a3c61a413d27150ec9bc202',1,'tds_bcp_fread(TDSSOCKET *tds, TDSICONV *char_conv, FILE *stream, const char *terminator, size_t term_len, char **outbuf, size_t *outbytes):&#160;bulk.c'],['../a00434.html#a8184311543c685f2ee0bcccfb725ca02',1,'tds_bcp_fread(TDSSOCKET *tds, TDSICONV *conv, FILE *stream, const char *terminator, size_t term_len, char **outbuf, size_t *outbytes):&#160;bulk.c']]],
  ['tds_5fbcp_5finit',['tds_bcp_init',['../a00248.html#ac6610c72bd31bad5378f760fa9b12d66',1,'tds_bcp_init(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c'],['../a00434.html#ac6610c72bd31bad5378f760fa9b12d66',1,'tds_bcp_init(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c']]],
  ['tds_5fbcp_5frow_5ffree',['tds_bcp_row_free',['../a00248.html#a7c4f2b050cd1a747604aa305d6877de7',1,'bulk.c']]],
  ['tds_5fbcp_5fsend_5frecord',['tds_bcp_send_record',['../a00248.html#adbc0876f3d1eae0c26e7a1abe37419fe',1,'tds_bcp_send_record(TDSSOCKET *tds, TDSBCPINFO *bcpinfo, tds_bcp_get_col_data get_col_data, tds_bcp_null_error ignored, int offset):&#160;bulk.c'],['../a00434.html#ad9e44450025cbcee1ad81d7e5a2cc099',1,'tds_bcp_send_record(TDSSOCKET *tds, TDSBCPINFO *bcpinfo, tds_bcp_get_col_data get_col_data, tds_bcp_null_error null_error, int offset):&#160;bulk.c']]],
  ['tds_5fbcp_5fstart',['tds_bcp_start',['../a00248.html#a8208eef2a3974ae1f0cf3c8c8ab011ce',1,'tds_bcp_start(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c'],['../a00434.html#a8208eef2a3974ae1f0cf3c8c8ab011ce',1,'tds_bcp_start(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c']]],
  ['tds_5fbcp_5fstart_5fcopy_5fin',['tds_bcp_start_copy_in',['../a00248.html#a5eec23828b0610c58de248c4edb53879',1,'tds_bcp_start_copy_in(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c'],['../a00434.html#a5eec23828b0610c58de248c4edb53879',1,'tds_bcp_start_copy_in(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c']]],
  ['tds_5fbcp_5fstart_5finsert_5fstmt',['tds_bcp_start_insert_stmt',['../a00248.html#ab4d7e5309152f54613d52c8469a07fd8',1,'bulk.c']]],
  ['tds_5fbcpcoldata',['tds_bcpcoldata',['../a01125.html',1,'']]],
  ['tds_5fbcpinfo',['tds_bcpinfo',['../a01197.html',1,'']]],
  ['tds_5fblob',['tds_blob',['../a01113.html',1,'']]],
  ['tds_5fcanonical_5fcharset',['tds_canonical_charset',['../a00531.html#ga38c0ac641a8c6e25e91ee9205c3c50c5',1,'iconv.c']]],
  ['tds_5fcanonical_5fcharset_5fname',['tds_canonical_charset_name',['../a00531.html#ga6561d1dba1a04c168431b16ec17d7e4c',1,'tds_canonical_charset_name(const char *charset_name):&#160;iconv.c'],['../a00531.html#ga6561d1dba1a04c168431b16ec17d7e4c',1,'tds_canonical_charset_name(const char *charset_name):&#160;iconv.c']]],
  ['tds_5fcapabilities',['tds_capabilities',['../a01097.html',1,'']]],
  ['tds_5fcapability_5ftype',['tds_capability_type',['../a01093.html',1,'']]],
  ['tds_5fclose_5fsocket',['tds_close_socket',['../a00534.html#ga3e3f76009fce5ceedb2f42bb2c9aed2e',1,'tds_close_socket(TDSSOCKET *tds):&#160;net.c'],['../a00534.html#ga3e3f76009fce5ceedb2f42bb2c9aed2e',1,'tds_close_socket(TDSSOCKET *tds):&#160;net.c']]],
  ['tds_5fcolumn',['tds_column',['../a01133.html',1,'']]],
  ['tds_5fcolumn_5ffuncs',['tds_column_funcs',['../a01129.html',1,'']]],
  ['tds_5fcompiletime_5fsettings',['tds_compiletime_settings',['../a01069.html',1,'tds_compiletime_settings'],['../a00434.html#ab30e42bf2bf063932ecd1a8212f617f0',1,'TDS_COMPILETIME_SETTINGS():&#160;tds.h']]],
  ['tds_5fcondition',['tds_condition',['../a01205.html',1,'']]],
  ['tds_5fconfig_5fverstr',['tds_config_verstr',['../a00529.html#gade94d7e89ba1f668c82be0b00a7f5cd7',1,'tds_config_verstr(const char *tdsver, TDSLOGIN *login):&#160;config.c'],['../a00529.html#gade94d7e89ba1f668c82be0b00a7f5cd7',1,'tds_config_verstr(const char *tdsver, TDSLOGIN *login):&#160;config.c']]],
  ['tds_5fconnection',['tds_connection',['../a01189.html',1,'']]],
  ['tds_5fcontext',['tds_context',['../a01173.html',1,'']]],
  ['tds_5fconvert',['tds_convert',['../a00530.html#gaa865e08f7ad70ef92b111c2ea3657457',1,'tds_convert(const TDSCONTEXT *tds_ctx, int srctype, const TDS_CHAR *src, TDS_UINT srclen, int desttype, CONV_RESULT *cr):&#160;convert.c'],['../a00530.html#gaa865e08f7ad70ef92b111c2ea3657457',1,'tds_convert(const TDSCONTEXT *context, int srctype, const TDS_CHAR *src, TDS_UINT srclen, int desttype, CONV_RESULT *cr):&#160;convert.c']]],
  ['tds_5fconvert_5fstream',['tds_convert_stream',['../a01330.html#a9d8eb43a81ff58ab423dce0ce95b9564',1,'stream.c']]],
  ['tds_5fconvert_5fstring',['tds_convert_string',['../a00533.html#ga024bc5482366735070befd6f4af59f71',1,'tds_convert_string(TDSSOCKET *tds, TDSICONV *char_conv, const char *s, int len, size_t *out_len):&#160;query.c'],['../a00533.html#ga024bc5482366735070befd6f4af59f71',1,'tds_convert_string(TDSSOCKET *tds, TDSICONV *char_conv, const char *s, int len, size_t *out_len):&#160;query.c']]],
  ['tds_5fcopy_5fstream',['tds_copy_stream',['../a01330.html#a2b8e3379c38cd2bce28b90cb199c2aa9',1,'stream.c']]],
  ['tds_5fcount_5fplaceholders',['tds_count_placeholders',['../a00533.html#gaaa7b4d37bf796019e72f25c6e7fe7bea',1,'tds_count_placeholders(const char *query):&#160;query.c'],['../a00533.html#gaaa7b4d37bf796019e72f25c6e7fe7bea',1,'tds_count_placeholders(const char *query):&#160;query.c']]],
  ['tds_5fcount_5fplaceholders_5fucs2le',['tds_count_placeholders_ucs2le',['../a00533.html#ga0cd19215e9169ea299a6c9cbf5b2fb60',1,'query.c']]],
  ['tds_5fctx',['tds_ctx',['../a00585.html#afb3fb2d591c0f75b9412f8ca77e2629d',1,'dblib_context']]],
  ['tds_5fctx_5fref_5fcount',['tds_ctx_ref_count',['../a00585.html#ad01d901acbc92e8c369e6a6c784d7446',1,'dblib_context']]],
  ['tds_5fcursor',['tds_cursor',['../a01157.html',1,'']]],
  ['tds_5fcursor_5fcheck_5fallocated',['tds_cursor_check_allocated',['../a00533.html#ga2c6da4886cc30af02546a3bc2ebcae5d',1,'query.c']]],
  ['tds_5fcursor_5fdealloc',['tds_cursor_dealloc',['../a00533.html#gab25de0567ac096e8f8e88490eeddf562',1,'tds_cursor_dealloc(TDSSOCKET *tds, TDSCURSOR *cursor):&#160;query.c'],['../a00533.html#gab25de0567ac096e8f8e88490eeddf562',1,'tds_cursor_dealloc(TDSSOCKET *tds, TDSCURSOR *cursor):&#160;query.c']]],
  ['tds_5fcursor_5fstatus',['tds_cursor_status',['../a01153.html',1,'']]],
  ['tds_5fdatain_5fstream',['tds_datain_stream',['../a01049.html',1,'']]],
  ['tds_5fdatain_5fstream_5finit',['tds_datain_stream_init',['../a01330.html#abc3a77c8aa28842e7f28583cbabc1415',1,'stream.c']]],
  ['tds_5fdatain_5fstream_5fread',['tds_datain_stream_read',['../a01330.html#a04b537d889f7d4c9b9701eb81baf7efd',1,'stream.c']]],
  ['tds_5fdataout_5fstream',['tds_dataout_stream',['../a01053.html',1,'']]],
  ['tds_5fdataout_5fstream_5finit',['tds_dataout_stream_init',['../a01330.html#aa038a9125979f8f0915dbd53cbf27e5a',1,'stream.c']]],
  ['tds_5fdataout_5fstream_5fwrite',['tds_dataout_stream_write',['../a01330.html#ae38a590ee08cf398e7adef536ac94538',1,'stream.c']]],
  ['tds_5fdatecrack',['tds_datecrack',['../a00530.html#ga883855e6e3793de6684b21db39c756c4',1,'tds_datecrack(TDS_INT datetype, const void *di, TDSDATEREC *dr):&#160;convert.c'],['../a00530.html#ga883855e6e3793de6684b21db39c756c4',1,'tds_datecrack(TDS_INT datetype, const void *di, TDSDATEREC *dr):&#160;convert.c']]],
  ['tds_5fdatetimeall',['TDS_DATETIMEALL',['../a01077.html',1,'']]],
  ['tds_5fdblib_5fdbprocess',['tds_dblib_dbprocess',['../a00901.html',1,'']]],
  ['tds_5fdblib_5floginrec',['tds_dblib_loginrec',['../a00869.html',1,'']]],
  ['tds_5fdead',['TDS_DEAD',['../a00434.html#a87cdae58f91ebe9229206bf0628f8e33af087b64970a1fb35bbcf1bc6ea7a643d',1,'tds.h']]],
  ['tds_5fdeferred_5fcursor_5fdealloc',['tds_deferred_cursor_dealloc',['../a00533.html#ga57bd0fabe5bcdeb3ef091259b3a7c1fc',1,'tds_deferred_cursor_dealloc(TDSCONNECTION *conn, TDSCURSOR *cursor):&#160;query.c'],['../a00533.html#ga57bd0fabe5bcdeb3ef091259b3a7c1fc',1,'tds_deferred_cursor_dealloc(TDSCONNECTION *conn, TDSCURSOR *cursor):&#160;query.c']]],
  ['tds_5fdeferred_5funprepare',['tds_deferred_unprepare',['../a00533.html#ga9f80fdf732b084aef7de7a323261aa61',1,'tds_deferred_unprepare(TDSCONNECTION *conn, TDSDYNAMIC *dyn):&#160;query.c'],['../a00533.html#ga9f80fdf732b084aef7de7a323261aa61',1,'tds_deferred_unprepare(TDSCONNECTION *conn, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fdetach_5fresults',['tds_detach_results',['../a00532.html#ga1d60bf443e274797b1d1a9e7418ab962',1,'tds_detach_results(TDSRESULTINFO *info):&#160;mem.c'],['../a00532.html#ga1d60bf443e274797b1d1a9e7418ab962',1,'tds_detach_results(TDSRESULTINFO *info):&#160;mem.c']]],
  ['tds_5fdone_5fcancelled',['TDS_DONE_CANCELLED',['../a00434.html#aa8d8044be84bcde003f28ec25a77519ca202254cfd6784404cf1aa22bc7147c86',1,'tds.h']]],
  ['tds_5fdone_5fcount',['TDS_DONE_COUNT',['../a00434.html#aa8d8044be84bcde003f28ec25a77519caf17d0c6591e318014c806a10c2f0270b',1,'tds.h']]],
  ['tds_5fdone_5ferror',['TDS_DONE_ERROR',['../a00434.html#aa8d8044be84bcde003f28ec25a77519caa9d79a3b62e3321332223ac3d1a5b18d',1,'tds.h']]],
  ['tds_5fdone_5ffinal',['TDS_DONE_FINAL',['../a00434.html#aa8d8044be84bcde003f28ec25a77519ca7ed9046db24ad78bb94c2b12d6e11f46',1,'tds.h']]],
  ['tds_5fdone_5finxact',['TDS_DONE_INXACT',['../a00434.html#aa8d8044be84bcde003f28ec25a77519cac79a30d1a0bac125e77d87f5d87bc2b2',1,'tds.h']]],
  ['tds_5fdone_5fmore_5fresults',['TDS_DONE_MORE_RESULTS',['../a00434.html#aa8d8044be84bcde003f28ec25a77519ca688b8bf555ce6ae72f3e047177bfc966',1,'tds.h']]],
  ['tds_5fdone_5fproc',['TDS_DONE_PROC',['../a00434.html#aa8d8044be84bcde003f28ec25a77519cae170f368306f421d507c6f08e4d48d9a',1,'tds.h']]],
  ['tds_5fdone_5fsrverror',['TDS_DONE_SRVERROR',['../a00434.html#aa8d8044be84bcde003f28ec25a77519ca7bfe89d6f8fc309eae412ad0a503e34c',1,'tds.h']]],
  ['tds_5fdstr',['tds_dstr',['../a01073.html',1,'']]],
  ['tds_5fdstr_5falloc',['tds_dstr_alloc',['../a00535.html#ga6aa14b8b717b51afcfb65bd55143689d',1,'tdsstring.c']]],
  ['tds_5fdstr_5fbuf',['tds_dstr_buf',['../a00535.html#ga8fa35e3ff06ef0b7d0d642cf50282ab8',1,'string.h']]],
  ['tds_5fdstr_5fcopy',['tds_dstr_copy',['../a00535.html#gad96366d9fa93bfc283cef1299fbe97ab',1,'tdsstring.c']]],
  ['tds_5fdstr_5fcopyn',['tds_dstr_copyn',['../a00535.html#ga656718f240d7403f986ae887d84a6ca1',1,'tdsstring.c']]],
  ['tds_5fdstr_5fcstr',['tds_dstr_cstr',['../a00535.html#ga3340b488ed37845018e34572450e64c6',1,'string.h']]],
  ['tds_5fdstr_5fdup',['tds_dstr_dup',['../a00535.html#ga4e6d9fa6f9b9551a5a3390e10a5322e6',1,'tdsstring.c']]],
  ['tds_5fdstr_5fempty',['tds_dstr_empty',['../a00535.html#ga42d67780bd4fd442915780d4815fc743',1,'string.h']]],
  ['tds_5fdstr_5ffree',['tds_dstr_free',['../a00535.html#gaccd1c1c8ff938813578123963212388c',1,'tdsstring.c']]],
  ['tds_5fdstr_5fget',['tds_dstr_get',['../a00534.html#gafae08056186b143f3ef1399307dc9be7',1,'tds_dstr_get(TDSSOCKET *tds, DSTR *s, size_t len):&#160;read.c'],['../a00534.html#gafae08056186b143f3ef1399307dc9be7',1,'tds_dstr_get(TDSSOCKET *tds, DSTR *s, size_t len):&#160;read.c']]],
  ['tds_5fdstr_5finit',['tds_dstr_init',['../a00535.html#ga6c0aba5c6da921898768e7f6cf177ca7',1,'string.h']]],
  ['tds_5fdstr_5fisempty',['tds_dstr_isempty',['../a00535.html#gae6d3d12bd1f5f0c56df934a377c245d3',1,'string.h']]],
  ['tds_5fdstr_5flen',['tds_dstr_len',['../a00535.html#gaf0e232f3c35f2d8b43486e8708f7a8fc',1,'string.h']]],
  ['tds_5fdstr_5fset',['tds_dstr_set',['../a00535.html#gab78cc59b110df2817b00f9bed74c6ff1',1,'tdsstring.c']]],
  ['tds_5fdstr_5fsetlen',['tds_dstr_setlen',['../a00535.html#ga0cd7863ba7c2d2da4a193234472a3d14',1,'tdsstring.c']]],
  ['tds_5fdstr_5fzero',['tds_dstr_zero',['../a00535.html#ga339ba30216e2bd5bd076aa9dcd26f3c4',1,'tdsstring.c']]],
  ['tds_5fdynamic',['tds_dynamic',['../a01165.html',1,'']]],
  ['tds_5fdynamic_5fstream',['tds_dynamic_stream',['../a01065.html',1,'']]],
  ['tds_5fdynamic_5fstream_5finit',['tds_dynamic_stream_init',['../a01330.html#a4f9e40da6941cb9407d0da5bc3030517',1,'stream.c']]],
  ['tds_5fdynamic_5fstream_5fwrite',['tds_dynamic_stream_write',['../a01330.html#abaf688c85ea04a2392103d519a55d04e',1,'stream.c']]],
  ['tds_5fencoding',['tds_encoding',['../a01121.html',1,'tds_encoding'],['../a00434.html#a6a0febfe3d78cb085172d18282a8cfaf',1,'TDS_ENCODING():&#160;tds.h']]],
  ['tds_5fend',['tds_end',['../a00434.html#aa8d8044be84bcde003f28ec25a77519c',1,'tds.h']]],
  ['tds_5fenv',['tds_env',['../a01161.html',1,'']]],
  ['tds_5ferrno_5fmessage_5fflags',['tds_errno_message_flags',['../a00937.html',1,'']]],
  ['tds_5ferror_5fmessage',['tds_error_message',['../a00753.html',1,'']]],
  ['tds_5ffile_5fstream',['tds_file_stream',['../a00693.html',1,'']]],
  ['tds_5ffile_5fstream_5fread',['tds_file_stream_read',['../a00248.html#a1b83c9db016b481aa1fa0352f976d50d',1,'bulk.c']]],
  ['tds_5ffix_5fcolumn_5fsize',['tds_fix_column_size',['../a00533.html#ga440f0f469afad1eac4c008979873ccdd',1,'tds_fix_column_size(TDSSOCKET *tds, TDSCOLUMN *curcol):&#160;query.c'],['../a00533.html#ga440f0f469afad1eac4c008979873ccdd',1,'tds_fix_column_size(TDSSOCKET *tds, TDSCOLUMN *curcol):&#160;query.c']]],
  ['tds_5ffix_5flogin',['tds_fix_login',['../a00529.html#gacee4f06ba749b10ee9f2e5bb1c4a8910',1,'tds_fix_login(TDSLOGIN *login):&#160;config.c'],['../a00529.html#gacee4f06ba749b10ee9f2e5bb1c4a8910',1,'tds_fix_login(TDSLOGIN *login):&#160;config.c']]],
  ['tds_5fflush_5fpacket',['tds_flush_packet',['../a00534.html#ga5feb53554e8917a81bbbc332163a61fb',1,'tds_flush_packet(TDSSOCKET *tds):&#160;write.c'],['../a00534.html#ga5feb53554e8917a81bbbc332163a61fb',1,'tds_flush_packet(TDSSOCKET *tds):&#160;write.c']]],
  ['tds_5ffree_5finput_5fparams',['tds_free_input_params',['../a00532.html#gabdc5fee73b22345c02ab894e49ad7f95',1,'tds_free_input_params(TDSDYNAMIC *dyn):&#160;mem.c'],['../a00532.html#gabdc5fee73b22345c02ab894e49ad7f95',1,'tds_free_input_params(TDSDYNAMIC *dyn):&#160;mem.c']]],
  ['tds_5ffree_5fnamelist',['tds_free_namelist',['../a00536.html#ga21e9de33de9c8c492aa2f96c823596bb',1,'token.c']]],
  ['tds_5ffree_5fparam_5fresult',['tds_free_param_result',['../a00532.html#ga66cd6e3c5089ced9415a8a0e258d205a',1,'tds_free_param_result(TDSPARAMINFO *param_info):&#160;mem.c'],['../a00532.html#ga66cd6e3c5089ced9415a8a0e258d205a',1,'tds_free_param_result(TDSPARAMINFO *param_info):&#160;mem.c']]],
  ['tds_5ffuncs',['TDS_FUNCS',['../a00997.html',1,'']]],
  ['tds_5fgeneric_5fget',['tds_generic_get',['../a00260.html#abac4d689e0e31e80587f89247c6395a4',1,'data.c']]],
  ['tds_5fgeneric_5fput',['tds_generic_put',['../a00260.html#a84e17808683ba2dd956e811a42e23176',1,'data.c']]],
  ['tds_5fgeneric_5fput_5finfo',['tds_generic_put_info',['../a00260.html#aabd0e5f15615b5c141c525b76e746520',1,'data.c']]],
  ['tds_5fget_5fbyte',['tds_get_byte',['../a00534.html#ga0cb72d3f6943795c39db1fa692be0a58',1,'tds_get_byte(TDSSOCKET *tds):&#160;read.c'],['../a00534.html#ga0cb72d3f6943795c39db1fa692be0a58',1,'tds_get_byte(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fget_5fchar_5fdata',['tds_get_char_data',['../a00534.html#ga8d214089b6e97fc0da5e0be09f216d73',1,'tds_get_char_data(TDSSOCKET *tds, char *row_buffer, size_t wire_size, TDSCOLUMN *curcol):&#160;read.c'],['../a00534.html#ga8d214089b6e97fc0da5e0be09f216d73',1,'tds_get_char_data(TDSSOCKET *tds, char *dest, size_t wire_size, TDSCOLUMN *curcol):&#160;read.c']]],
  ['tds_5fget_5fcolumn_5fdeclaration',['tds_get_column_declaration',['../a00533.html#ga50d62edeb2a432e2dc668263f3f958ff',1,'tds_get_column_declaration(TDSSOCKET *tds, TDSCOLUMN *curcol, char *out):&#160;query.c'],['../a00533.html#ga50d62edeb2a432e2dc668263f3f958ff',1,'tds_get_column_declaration(TDSSOCKET *tds, TDSCOLUMN *curcol, char *out):&#160;query.c']]],
  ['tds_5fget_5fcompiletime_5fsettings',['tds_get_compiletime_settings',['../a00529.html#ga860690ac47a80f74c83b25cbd8d7703d',1,'tds_get_compiletime_settings(void):&#160;config.c'],['../a00529.html#ga860690ac47a80f74c83b25cbd8d7703d',1,'tds_get_compiletime_settings(void):&#160;config.c']]],
  ['tds_5fget_5fconversion_5ftype',['tds_get_conversion_type',['../a00434.html#a0383d5dcb629582266a442f0f0dbd13a',1,'tds_types.h']]],
  ['tds_5fget_5fdata_5finfo',['tds_get_data_info',['../a00536.html#gad9b6b86f48be077fb44ac603845a0c27',1,'token.c']]],
  ['tds_5fget_5fdynid',['tds_get_dynid',['../a00532.html#ga501af7e6186e59c257729599a044a30b',1,'mem.c']]],
  ['tds_5fget_5fhome_5ffile',['tds_get_home_file',['../a00529.html#gaf49eca946d1b2457e189de7207e3670c',1,'config.c']]],
  ['tds_5fget_5fhomedir',['tds_get_homedir',['../a00434.html#a6fb8c78f678c0016c12096765ab2f5c1',1,'threadsafe.c']]],
  ['tds_5fget_5flocale',['tds_get_locale',['../a00434.html#af43163dc067b230b2236a619a067c675',1,'locale.c']]],
  ['tds_5fget_5fn',['tds_get_n',['../a00534.html#gae7d9c4e1a079e1d0aa0252732631e8c4',1,'tds_get_n(TDSSOCKET *tds, void *dest, size_t need):&#160;read.c'],['../a00534.html#gae7d9c4e1a079e1d0aa0252732631e8c4',1,'tds_get_n(TDSSOCKET *tds, void *dest, size_t n):&#160;read.c']]],
  ['tds_5fget_5fnull_5ftype',['tds_get_null_type',['../a00530.html#ga68e3a76fd7b0a77614765826a8ab5be8',1,'tds_get_null_type(TDS_SERVER_TYPE srctype):&#160;convert.c'],['../a00530.html#ga68e3a76fd7b0a77614765826a8ab5be8',1,'tds_get_null_type(TDS_SERVER_TYPE srctype):&#160;convert.c']]],
  ['tds_5fget_5fsize_5fby_5ftype',['tds_get_size_by_type',['../a00434.html#a4c070147d189dede5e08a2dc66852678',1,'tds_types.h']]],
  ['tds_5fget_5fstring',['tds_get_string',['../a00534.html#ga90f080e6e9448feac15dee1370d66802',1,'tds_get_string(TDSSOCKET *tds, size_t string_len, char *dest, size_t dest_size):&#160;read.c'],['../a00534.html#ga90f080e6e9448feac15dee1370d66802',1,'tds_get_string(TDSSOCKET *tds, size_t string_len, char *dest, size_t dest_size):&#160;read.c']]],
  ['tds_5fget_5ftoken_5fsize',['tds_get_token_size',['../a00536.html#ga995b82e53aeac5bede01ef16e9aeaa65',1,'tds_get_token_size(int marker):&#160;token.c'],['../a00536.html#ga995b82e53aeac5bede01ef16e9aeaa65',1,'tds_get_token_size(int marker):&#160;token.c']]],
  ['tds_5fget_5fuint',['tds_get_uint',['../a00534.html#ga9ac121c269e203337a48c5bf8afc48c3',1,'tds_get_uint(TDSSOCKET *tds):&#160;read.c'],['../a00534.html#ga9ac121c269e203337a48c5bf8afc48c3',1,'tds_get_uint(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fget_5fuint8',['tds_get_uint8',['../a00534.html#ga8ab6c87318eaf15ea17a9575763f7809',1,'tds_get_uint8(TDSSOCKET *tds):&#160;read.c'],['../a00534.html#ga8ab6c87318eaf15ea17a9575763f7809',1,'tds_get_uint8(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fget_5fusmallint',['tds_get_usmallint',['../a00534.html#gad38aa5b9547817854ccba1fcc7855861',1,'tds_get_usmallint(TDSSOCKET *tds):&#160;read.c'],['../a00534.html#gad38aa5b9547817854ccba1fcc7855861',1,'tds_get_usmallint(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fget_5fvarint_5fsize',['tds_get_varint_size',['../a00434.html#a68855f1251759a6b7338635306ab0041',1,'tds_types.h']]],
  ['tds_5fgetservice',['tds_getservice',['../a00434.html#a3a2add5890ed468e36d780d29263ae22',1,'threadsafe.c']]],
  ['tds_5fgoodread',['tds_goodread',['../a00534.html#ga6f2ae00407f59fb1ab280fa44a56295e',1,'tds_goodread(TDSSOCKET *tds, unsigned char *buf, int buflen):&#160;net.c'],['../a00534.html#ga6f2ae00407f59fb1ab280fa44a56295e',1,'tds_goodread(TDSSOCKET *tds, unsigned char *buf, int buflen):&#160;net.c']]],
  ['tds_5fgoodwrite',['tds_goodwrite',['../a00534.html#ga2734407109c834c5dda7ff8a45c71230',1,'tds_goodwrite(TDSSOCKET *tds, const unsigned char *buffer, size_t buflen):&#160;net.c'],['../a00534.html#ga2734407109c834c5dda7ff8a45c71230',1,'tds_goodwrite(TDSSOCKET *tds, const unsigned char *buffer, size_t buflen):&#160;net.c']]],
  ['tds_5fheaders',['tds_headers',['../a01105.html',1,'']]],
  ['tds_5ficonv',['tds_iconv',['../a00531.html#ga87db49044919f1bc84c0ff5e9ab00304',1,'tds_iconv(TDSSOCKET *tds, TDSICONV *conv, TDS_ICONV_DIRECTION io, const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft):&#160;iconv.c'],['../a00531.html#ga87db49044919f1bc84c0ff5e9ab00304',1,'tds_iconv(TDSSOCKET *tds, TDSICONV *char_conv, TDS_ICONV_DIRECTION io, const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft):&#160;iconv.c']]],
  ['tds_5ficonv_5falloc',['tds_iconv_alloc',['../a01342.html#a026957dbbd994b48b571a63405f427cd',1,'tds_iconv_alloc(TDSCONNECTION *conn):&#160;iconv.c'],['../a00434.html#a026957dbbd994b48b571a63405f427cd',1,'tds_iconv_alloc(TDSCONNECTION *conn):&#160;iconv.c']]],
  ['tds_5ficonv_5ffrom_5fcollate',['tds_iconv_from_collate',['../a00531.html#gaed775f7fcca42b5c2a53f9508c140259',1,'tds_iconv_from_collate(TDSCONNECTION *conn, TDS_UCHAR collate[5]):&#160;iconv.c'],['../a00531.html#gaed775f7fcca42b5c2a53f9508c140259',1,'tds_iconv_from_collate(TDSCONNECTION *conn, TDS_UCHAR collate[5]):&#160;iconv.c']]],
  ['tds_5ficonv_5fget_5finfo',['tds_iconv_get_info',['../a00531.html#gac85bc9c101048a124707c7050035e30f',1,'iconv.c']]],
  ['tds_5ficonv_5finfo_5finit',['tds_iconv_info_init',['../a00531.html#ga3a7a7b4d6ed344127e164dd0b443d790',1,'iconv.c']]],
  ['tds_5ficonv_5finit',['tds_iconv_init',['../a01342.html#a89de4d12be43b135ad355236717e9cbb',1,'iconv.c']]],
  ['tds_5fidle',['TDS_IDLE',['../a00434.html#a87cdae58f91ebe9229206bf0628f8e33ad1586abc1f75b7f3d640b994afe310e9',1,'tds.h']]],
  ['tds_5finit_5flogin',['tds_init_login',['../a00532.html#ga2ef389ac3b0cddec76bf8f1c0951bc9c',1,'tds_init_login(TDSLOGIN *login, TDSLOCALE *locale):&#160;mem.c'],['../a00532.html#ga2ef389ac3b0cddec76bf8f1c0951bc9c',1,'tds_init_login(TDSLOGIN *login, TDSLOCALE *locale):&#160;mem.c']]],
  ['tds_5finput_5fstream',['tds_input_stream',['../a01041.html',1,'']]],
  ['tds_5fis_5fmssql',['TDS_IS_MSSQL',['../a00434.html#a07e9371c3e72b9e319f4c14e6fc2c20f',1,'tds.h']]],
  ['tds_5fis_5fsybase',['TDS_IS_SYBASE',['../a00434.html#a4840433488d0c66601ff4002a54b41d7',1,'tds.h']]],
  ['tds_5flocale',['tds_locale',['../a01109.html',1,'']]],
  ['tds_5flogin',['tds_login',['../a01101.html',1,'']]],
  ['tds_5flookup_5fdynamic',['tds_lookup_dynamic',['../a00536.html#ga595fe391e60a71bd98ffd53b4c015e44',1,'tds_lookup_dynamic(TDSCONNECTION *conn, const char *id):&#160;token.c'],['../a00536.html#ga595fe391e60a71bd98ffd53b4c015e44',1,'tds_lookup_dynamic(TDSCONNECTION *conn, const char *id):&#160;token.c']]],
  ['tds_5flookup_5fhost',['tds_lookup_host',['../a00529.html#gaa17936ef93e1c68833c4aab769bd90d9',1,'tds_lookup_host(const char *servername):&#160;config.c'],['../a00529.html#gaa17936ef93e1c68833c4aab769bd90d9',1,'tds_lookup_host(const char *servername):&#160;config.c']]],
  ['tds_5flookup_5fport',['tds_lookup_port',['../a00529.html#ga45281d1cb2ac649db65d80bb3ff06b66',1,'config.c']]],
  ['tds_5fmay_5falias',['TDS_MAY_ALIAS',['../a00909.html',1,'']]],
  ['tds_5fmessage',['tds_message',['../a01145.html',1,'']]],
  ['tds_5fmicrosoft_5fdbdaterec',['tds_microsoft_dbdaterec',['../a01285.html',1,'']]],
  ['tds_5fmicrosoft_5fdbdaterec2',['tds_microsoft_dbdaterec2',['../a01293.html',1,'']]],
  ['tds_5fms_5fver',['TDS_MS_VER',['../a00434.html#a1f5fb9d2184949ed566c8ce308a4e91e',1,'tds.h']]],
  ['tds_5fmultiple',['tds_multiple',['../a01169.html',1,'']]],
  ['tds_5fneeds_5funprepare',['tds_needs_unprepare',['../a00533.html#ga05ac7bab753d19b6ba1ffc7505d8fcd0',1,'tds_needs_unprepare(TDSCONNECTION *conn, TDSDYNAMIC *dyn):&#160;query.c'],['../a00533.html#ga05ac7bab753d19b6ba1ffc7505d8fcd0',1,'tds_needs_unprepare(TDSCONNECTION *conn, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fnext_5fplaceholder',['tds_next_placeholder',['../a00533.html#ga6455b2991afbf7da90270787f2059d31',1,'tds_next_placeholder(const char *start):&#160;query.c'],['../a00533.html#ga6455b2991afbf7da90270787f2059d31',1,'tds_next_placeholder(const char *start):&#160;query.c']]],
  ['tds_5fnext_5fplaceholder_5fucs2le',['tds_next_placeholder_ucs2le',['../a00533.html#gaa823973b74efdf1ff00f340496bff614',1,'query.c']]],
  ['tds_5fntlm_5fauth',['tds_ntlm_auth',['../a00705.html',1,'']]],
  ['tds_5fntlm_5fget_5fauth',['tds_ntlm_get_auth',['../a00528.html#ga679f2d22b4a4bdefe0fa475d63503778',1,'tds_ntlm_get_auth(TDSSOCKET *tds):&#160;challenge.c'],['../a00528.html#ga679f2d22b4a4bdefe0fa475d63503778',1,'tds_ntlm_get_auth(TDSSOCKET *tds):&#160;challenge.c']]],
  ['tds_5fnumeric_5fbytes_5fper_5fprec',['tds_numeric_bytes_per_prec',['../a00434.html#a4da9eedb6322f7dfca89d5d89be7b374',1,'numeric.c']]],
  ['tds_5fnumeric_5fto_5fstring',['tds_numeric_to_string',['../a00434.html#a622da936832b0337742da956be123719',1,'numeric.c']]],
  ['tds_5foption_5farg',['tds_option_arg',['../a01085.html',1,'']]],
  ['tds_5foutput_5fstream',['tds_output_stream',['../a01045.html',1,'']]],
  ['tds_5fpacket',['tds_packet',['../a01181.html',1,'']]],
  ['tds_5fparsed_5fparam',['TDS_PARSED_PARAM',['../a01001.html',1,'']]],
  ['tds_5fpbcb',['tds_pbcb',['../a00689.html',1,'']]],
  ['tds_5fpeek',['tds_peek',['../a00534.html#ga221e98a9c8be96ec6c8547891e1b53af',1,'tds_peek(TDSSOCKET *tds):&#160;read.c'],['../a00534.html#ga221e98a9c8be96ec6c8547891e1b53af',1,'tds_peek(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fpending',['TDS_PENDING',['../a00434.html#a87cdae58f91ebe9229206bf0628f8e33a00f6d5ac5560f2f44661e599241849a8',1,'tds.h']]],
  ['tds_5fpoll_5fwakeup',['tds_poll_wakeup',['../a01185.html',1,'']]],
  ['tds_5fpool',['tds_pool',['../a00669.html',1,'']]],
  ['tds_5fpool_5fevent',['tds_pool_event',['../a00653.html',1,'']]],
  ['tds_5fpool_5fmember',['tds_pool_member',['../a00665.html',1,'']]],
  ['tds_5fpool_5fsocket',['tds_pool_socket',['../a00657.html',1,'']]],
  ['tds_5fpool_5fuser',['tds_pool_user',['../a00661.html',1,'']]],
  ['tds_5fpr_5fop',['tds_pr_op',['../a00536.html#ga62dc14d21453e88e24880ee0acaca73a',1,'token.c']]],
  ['tds_5fprdatatype',['tds_prdatatype',['../a00077.html#ac7a199aaeb82935f6d1dda2be551a089',1,'dblib.c']]],
  ['tds_5fprocess_5fauth',['tds_process_auth',['../a00536.html#ga4e1e52e09b0c27a9b9f53eb6b539afce',1,'token.c']]],
  ['tds_5fprocess_5fcancel',['tds_process_cancel',['../a00536.html#gaf233e79967f82f4e0dd4d11524917a34',1,'tds_process_cancel(TDSSOCKET *tds):&#160;token.c'],['../a00536.html#gaf233e79967f82f4e0dd4d11524917a34',1,'tds_process_cancel(TDSSOCKET *tds):&#160;token.c']]],
  ['tds_5fprocess_5fcol_5ffmt',['tds_process_col_fmt',['../a00536.html#ga4e3dd9d3614f5f0433b78b761dd68741',1,'token.c']]],
  ['tds_5fprocess_5fcol_5fname',['tds_process_col_name',['../a00536.html#ga905d2fa5e1b602817bd16bb0fcf9eadb',1,'token.c']]],
  ['tds_5fprocess_5fcolinfo',['tds_process_colinfo',['../a00536.html#ga22c7f413d43fc0d511e122a3de389166',1,'token.c']]],
  ['tds_5fprocess_5fcompute',['tds_process_compute',['../a00536.html#ga6fcb37d5addebdc1af9f34ebc59fd7a8',1,'token.c']]],
  ['tds_5fprocess_5fcompute_5fnames',['tds_process_compute_names',['../a00536.html#gae5b3e01f3d665f9e377de091f46f1ab9',1,'token.c']]],
  ['tds_5fprocess_5fcompute_5fresult',['tds_process_compute_result',['../a00536.html#gae3368ea80d0d8b13791ceb13ee5f19c9',1,'token.c']]],
  ['tds_5fprocess_5fcursor_5ftokens',['tds_process_cursor_tokens',['../a00536.html#ga315d875d90c64d12d61fc9e33b4dee96',1,'token.c']]],
  ['tds_5fprocess_5fdefault_5ftokens',['tds_process_default_tokens',['../a00536.html#ga39453d084f3f780ac4602d4abf2839f7',1,'token.c']]],
  ['tds_5fprocess_5fdyn_5fresult',['tds_process_dyn_result',['../a00536.html#ga416cf119c1d4a0fca27dc5b50c261358',1,'token.c']]],
  ['tds_5fprocess_5fdynamic',['tds_process_dynamic',['../a00536.html#ga5cfc0340d8d717e67f60037e029b2142',1,'token.c']]],
  ['tds_5fprocess_5fend',['tds_process_end',['../a00536.html#ga7a081cf9bb8f04ead12f0299fb7c4cd9',1,'token.c']]],
  ['tds_5fprocess_5fenv_5fchg',['tds_process_env_chg',['../a00536.html#ga3e1b4df4410a86a563a8c155e7799720',1,'token.c']]],
  ['tds_5fprocess_5finfo',['tds_process_info',['../a00536.html#ga65a2316369529731732f200c190d05d6',1,'token.c']]],
  ['tds_5fprocess_5flogin_5ftokens',['tds_process_login_tokens',['../a00536.html#ga93945b42d45ee28ae1296b35a1c1e9bb',1,'tds_process_login_tokens(TDSSOCKET *tds):&#160;token.c'],['../a00536.html#ga93945b42d45ee28ae1296b35a1c1e9bb',1,'tds_process_login_tokens(TDSSOCKET *tds):&#160;token.c']]],
  ['tds_5fprocess_5fnbcrow',['tds_process_nbcrow',['../a00536.html#gaf7264c9eb3aa7a73358a4c65f02d3d3c',1,'token.c']]],
  ['tds_5fprocess_5fparam_5fresult',['tds_process_param_result',['../a00536.html#gacb3354443bcefe7a500a500a4904cc05',1,'token.c']]],
  ['tds_5fprocess_5fparam_5fresult_5ftokens',['tds_process_param_result_tokens',['../a00536.html#ga9fdef8228d29cab7fa9098f07fa73fba',1,'token.c']]],
  ['tds_5fprocess_5fparams_5fresult_5ftoken',['tds_process_params_result_token',['../a00536.html#ga7b18c0911a9dc69939577b39eb64725d',1,'token.c']]],
  ['tds_5fprocess_5fpending_5fcloses',['tds_process_pending_closes',['../a00536.html#ga69902dffb299d62a799888e0fa3ccd68',1,'token.c']]],
  ['tds_5fprocess_5frow',['tds_process_row',['../a00536.html#gaad814dd6e35aee8332035d06dc8b5d65',1,'token.c']]],
  ['tds_5fprocess_5fsimple_5fquery',['tds_process_simple_query',['../a00536.html#gaeeb1562044786ea17bea361ed83e6946',1,'tds_process_simple_query(TDSSOCKET *tds):&#160;token.c'],['../a00536.html#gaeeb1562044786ea17bea361ed83e6946',1,'tds_process_simple_query(TDSSOCKET *tds):&#160;token.c']]],
  ['tds_5fprocess_5ftabname',['tds_process_tabname',['../a00536.html#gaeec59bca9bd0c5388e245f0d19d9c81a',1,'token.c']]],
  ['tds_5fprocess_5ftokens',['tds_process_tokens',['../a00536.html#gabfc9de1d1fe718818caf63a4be4035a6',1,'tds_process_tokens(TDSSOCKET *tds, TDS_INT *result_type, int *done_flags, unsigned flag):&#160;token.c'],['../a00536.html#gabfc9de1d1fe718818caf63a4be4035a6',1,'tds_process_tokens(TDSSOCKET *tds, TDS_INT *result_type, int *done_flags, unsigned flag):&#160;token.c']]],
  ['tds_5fprtype',['tds_prtype',['../a00536.html#ga0cf7e719115b0ae476753442d10505ab',1,'tds_prtype(int type):&#160;token.c'],['../a00536.html#ga0cf7e719115b0ae476753442d10505ab',1,'tds_prtype(int token):&#160;token.c']]],
  ['tds_5fput_5fdata',['tds_put_data',['../a00533.html#ga9fcc0a3932dcad530511395ef8a767fb',1,'query.c']]],
  ['tds_5fput_5fdata_5finfo',['tds_put_data_info',['../a00533.html#gafd74652c4722ddce4d642cc4209449d4',1,'query.c']]],
  ['tds_5fput_5fdata_5finfo_5flength',['tds_put_data_info_length',['../a00533.html#ga319d610d59b2cc669b7fe20c793122af',1,'query.c']]],
  ['tds_5fput_5fn_5fas_5fucs2',['TDS_PUT_N_AS_UCS2',['../a00533.html#ga62c3dc9946acb3ffd1b7ae43424f5b47',1,'query.c']]],
  ['tds_5fput_5fparam_5fas_5fstring',['tds_put_param_as_string',['../a00533.html#ga0e2e7230c425e925402d7856ff5b4b18',1,'query.c']]],
  ['tds_5fput_5fparams',['tds_put_params',['../a00533.html#ga28264995cf9616661f1fa788ac0d246d',1,'query.c']]],
  ['tds_5fput_5fstring',['tds_put_string',['../a00534.html#ga1fcaf8d488cc1390f106ce3ad0bf37b4',1,'tds_put_string(TDSSOCKET *tds, const char *s, int len):&#160;write.c'],['../a00534.html#ga1fcaf8d488cc1390f106ce3ad0bf37b4',1,'tds_put_string(TDSSOCKET *tds, const char *buf, int len):&#160;write.c']]],
  ['tds_5fput_5ftinyint',['tds_put_tinyint',['../a00434.html#adfc186758f4c1856c01746b5436aff74',1,'tds.h']]],
  ['tds_5fquery_5fflush_5fpacket',['tds_query_flush_packet',['../a00533.html#gada27f4cfce925240ad33b71b63ca692d',1,'query.c']]],
  ['tds_5fquote',['tds_quote',['../a00533.html#ga7efaa23c3b21158ffc963f85fbc3fdf4',1,'query.c']]],
  ['tds_5fquote_5fand_5fput',['tds_quote_and_put',['../a00533.html#ga26b26296d060dca75f6a43e9ac41e58d',1,'query.c']]],
  ['tds_5fquote_5fid',['tds_quote_id',['../a00533.html#ga8d8f2f1c91635ee95f30722208ae3043',1,'tds_quote_id(TDSSOCKET *tds, char *buffer, const char *id, int idlen):&#160;query.c'],['../a00533.html#ga8d8f2f1c91635ee95f30722208ae3043',1,'tds_quote_id(TDSSOCKET *tds, char *buffer, const char *id, int idlen):&#160;query.c']]],
  ['tds_5fquote_5fstring',['tds_quote_string',['../a00533.html#ga737b9fb9971fb425af5c722415ef0eac',1,'tds_quote_string(TDSSOCKET *tds, char *buffer, const char *str, int len):&#160;query.c'],['../a00533.html#ga737b9fb9971fb425af5c722415ef0eac',1,'tds_quote_string(TDSSOCKET *tds, char *buffer, const char *str, int len):&#160;query.c']]],
  ['tds_5fraw_5fmutex',['tds_raw_mutex',['../a01201.html',1,'']]],
  ['tds_5fread_5fconf_5ffile',['tds_read_conf_file',['../a00529.html#ga0a63cb612f245fd85e56cfea98ff8f3b',1,'tds_read_conf_file(TDSLOGIN *login, const char *server):&#160;config.c'],['../a00529.html#ga0a63cb612f245fd85e56cfea98ff8f3b',1,'tds_read_conf_file(TDSLOGIN *login, const char *server):&#160;config.c']]],
  ['tds_5fread_5fconf_5fsection',['tds_read_conf_section',['../a00529.html#ga6580a3a0a6063c8095a3c4405061e068',1,'tds_read_conf_section(FILE *in, const char *section, TDSCONFPARSE tds_conf_parse, void *param):&#160;config.c'],['../a00529.html#ga6580a3a0a6063c8095a3c4405061e068',1,'tds_read_conf_section(FILE *in, const char *section, TDSCONFPARSE tds_conf_parse, void *parse_param):&#160;config.c']]],
  ['tds_5fread_5fconfig_5finfo',['tds_read_config_info',['../a00529.html#ga9af192306186ddf39e09be0fd4ad8aaf',1,'tds_read_config_info(TDSSOCKET *tds, TDSLOGIN *login, TDSLOCALE *locale):&#160;config.c'],['../a00529.html#ga9af192306186ddf39e09be0fd4ad8aaf',1,'tds_read_config_info(TDSSOCKET *tds, TDSLOGIN *login, TDSLOCALE *locale):&#160;config.c']]],
  ['tds_5fread_5finterfaces',['tds_read_interfaces',['../a00529.html#ga6631af35ee817f93827c62bbda41674a',1,'config.c']]],
  ['tds_5fread_5fnamelist',['tds_read_namelist',['../a00536.html#gaeaaed2ea1d8c827da1a0f5b419524ae1',1,'token.c']]],
  ['tds_5fread_5fpacket',['tds_read_packet',['../a00534.html#ga410619783bdf2bb60b0f27a5578e0e07',1,'tds_read_packet(TDSSOCKET *tds):&#160;packet.c'],['../a00534.html#ga410619783bdf2bb60b0f27a5578e0e07',1,'tds_read_packet(TDSSOCKET *tds):&#160;packet.c']]],
  ['tds_5freading',['TDS_READING',['../a00434.html#a87cdae58f91ebe9229206bf0628f8e33a36ddbc8f326d6b297009a8fafd958529',1,'tds.h']]],
  ['tds_5frealloc',['tds_realloc',['../a00532.html#ga924cb9fb5d19dbd308ba0ce8c1a8a1d5',1,'tds_realloc(void **pp, size_t new_size):&#160;mem.c'],['../a00532.html#ga924cb9fb5d19dbd308ba0ce8c1a8a1d5',1,'tds_realloc(void **pp, size_t new_size):&#160;mem.c']]],
  ['tds_5frelease_5fdynamic',['tds_release_dynamic',['../a00532.html#gabf2fdb0def5388508602ee7dd2f49506',1,'tds_release_dynamic(TDSDYNAMIC **pdyn):&#160;mem.c'],['../a00532.html#gabf2fdb0def5388508602ee7dd2f49506',1,'tds_release_dynamic(TDSDYNAMIC **dyn):&#160;mem.c']]],
  ['tds_5fresult_5finfo',['tds_result_info',['../a01141.html',1,'']]],
  ['tds_5fsave_5fcontext',['tds_save_context',['../a00733.html',1,'']]],
  ['tds_5fsave_5fenv',['tds_save_env',['../a00729.html',1,'']]],
  ['tds_5fsave_5fmsg',['tds_save_msg',['../a00725.html',1,'']]],
  ['tds_5fselect',['tds_select',['../a00534.html#gad7aae89e32444ab30852fee056231403',1,'tds_select(TDSSOCKET *tds, unsigned tds_sel, int timeout_seconds):&#160;net.c'],['../a00534.html#gad7aae89e32444ab30852fee056231403',1,'tds_select(TDSSOCKET *tds, unsigned tds_sel, int timeout_seconds):&#160;net.c']]],
  ['tds_5fsend_5fcancel',['tds_send_cancel',['../a00533.html#ga11338742dc30fd0c2711f58eb830316f',1,'tds_send_cancel(TDSSOCKET *tds):&#160;query.c'],['../a00533.html#ga11338742dc30fd0c2711f58eb830316f',1,'tds_send_cancel(TDSSOCKET *tds):&#160;query.c']]],
  ['tds_5fsend_5femulated_5fexecute',['tds_send_emulated_execute',['../a00533.html#ga02c6ce3ff96369603a6ee4efee64caae',1,'query.c']]],
  ['tds_5fsend_5femulated_5frpc',['tds_send_emulated_rpc',['../a00533.html#gaf614c75ea8f7ad411e53dac0e2f91be4',1,'query.c']]],
  ['tds_5fsending',['TDS_SENDING',['../a00434.html#a87cdae58f91ebe9229206bf0628f8e33a2bad5be30bd85edc9495dae3d199d2c1',1,'tds.h']]],
  ['tds_5fset_5fcolumn_5ftype',['tds_set_column_type',['../a00260.html#a31604382d8b77257aad203f409155a29',1,'tds_set_column_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c'],['../a00434.html#a31604382d8b77257aad203f409155a29',1,'tds_set_column_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c']]],
  ['tds_5fset_5fcur_5fcursor',['tds_set_cur_cursor',['../a00533.html#ga34fb1084682cc31fe02a4a7946955a5a',1,'query.c']]],
  ['tds_5fset_5fcur_5fdyn',['tds_set_cur_dyn',['../a00533.html#gae8b7db85af16701fc0604eb117cbd4e4',1,'tds_set_cur_dyn(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c'],['../a00533.html#gae8b7db85af16701fc0604eb117cbd4e4',1,'tds_set_cur_dyn(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fset_5ficonv_5fname',['tds_set_iconv_name',['../a01342.html#a010ab1d181c8996f6a5984c9900eca6b',1,'iconv.c']]],
  ['tds_5fset_5finterfaces_5ffile_5floc',['tds_set_interfaces_file_loc',['../a00529.html#ga57cea6e376d7c2d28b811a5b0053210c',1,'tds_set_interfaces_file_loc(const char *interf):&#160;config.c'],['../a00529.html#ga57cea6e376d7c2d28b811a5b0053210c',1,'tds_set_interfaces_file_loc(const char *interfloc):&#160;config.c']]],
  ['tds_5fset_5fparam_5ftype',['tds_set_param_type',['../a00260.html#a86768d86059c5addf9a3f89edb1ef44e',1,'tds_set_param_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c'],['../a00434.html#a86768d86059c5addf9a3f89edb1ef44e',1,'tds_set_param_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c']]],
  ['tds_5fset_5fserver',['tds_set_server',['../a00434.html#a3ab8874994a0776acdaff797afdb710a',1,'login.c']]],
  ['tds_5fset_5fstate',['tds_set_state',['../a00434.html#a16db200d2281f76fe46fc1cbe37ca9df',1,'util.c']]],
  ['tds_5fskip_5fcomment',['tds_skip_comment',['../a00533.html#gaac7347ba9380d77d726648b85e9fab8f',1,'tds_skip_comment(const char *s):&#160;query.c'],['../a00533.html#gaac7347ba9380d77d726648b85e9fab8f',1,'tds_skip_comment(const char *s):&#160;query.c']]],
  ['tds_5fskip_5fcomment_5fucs2le',['tds_skip_comment_ucs2le',['../a00533.html#gab304fda9f325e852ba5c5252079d22e3',1,'query.c']]],
  ['tds_5fskip_5fquoted',['tds_skip_quoted',['../a00533.html#ga5dbe51ce9533218f2da23f69ff63dda4',1,'tds_skip_quoted(const char *s):&#160;query.c'],['../a00533.html#ga5dbe51ce9533218f2da23f69ff63dda4',1,'tds_skip_quoted(const char *s):&#160;query.c']]],
  ['tds_5fskip_5fquoted_5fucs2le',['tds_skip_quoted_ucs2le',['../a00533.html#ga2361ec4629aa0eac38f1702b03ed8185',1,'query.c']]],
  ['tds_5fsocket',['tds_socket',['../a01193.html',1,'']]],
  ['tds_5fsocket_5fread',['tds_socket_read',['../a00534.html#ga8560e2536fdcf8f1514d4fa14f90876c',1,'net.c']]],
  ['tds_5fsocket_5fset_5fnonblocking',['tds_socket_set_nonblocking',['../a00534.html#ga2a7429ff031f77023d1bf31339a266db',1,'tds_socket_set_nonblocking(TDS_SYS_SOCKET sock):&#160;net.c'],['../a00534.html#ga2a7429ff031f77023d1bf31339a266db',1,'tds_socket_set_nonblocking(TDS_SYS_SOCKET sock):&#160;net.c']]],
  ['tds_5fsocket_5fwrite',['tds_socket_write',['../a00534.html#gad6f81b48fbcfc18ce0b213dbbea47e30',1,'net.c']]],
  ['tds_5fstart_5fquery',['tds_start_query',['../a00533.html#ga0da385231bfa3dc49377e1fb2bea2c07',1,'tds_start_query(TDSSOCKET *tds, unsigned char packet_type):&#160;query.c'],['../a00533.html#ga0da385231bfa3dc49377e1fb2bea2c07',1,'tds_start_query(TDSSOCKET *tds, unsigned char packet_type):&#160;query.c']]],
  ['tds_5fstart_5fquery_5fhead',['tds_start_query_head',['../a00533.html#ga9ad2e6defce530a8778791cce0166ccd',1,'query.c']]],
  ['tds_5fstate',['TDS_STATE',['../a00434.html#a58f34a3a686a968357537c7486521b51',1,'tds.h']]],
  ['tds_5fstates',['tds_states',['../a00434.html#a87cdae58f91ebe9229206bf0628f8e33',1,'tds.h']]],
  ['tds_5fstaticin_5fstream',['tds_staticin_stream',['../a01057.html',1,'']]],
  ['tds_5fstaticin_5fstream_5finit',['tds_staticin_stream_init',['../a01330.html#aa9e1e45f0305622dd6aed9f8fe158581',1,'stream.c']]],
  ['tds_5fstaticin_5fstream_5fread',['tds_staticin_stream_read',['../a01330.html#a76b02f1fa5b79dc7e1ef2651a9afe3f7',1,'stream.c']]],
  ['tds_5fstaticout_5fstream',['tds_staticout_stream',['../a01061.html',1,'']]],
  ['tds_5fstaticout_5fstream_5finit',['tds_staticout_stream_init',['../a01330.html#a9fe0d3799d2e3bde49b614c9d0c3785d',1,'stream.c']]],
  ['tds_5fstaticout_5fstream_5fwrite',['tds_staticout_stream_write',['../a01330.html#a1d92ebe06f18378ac17ccfd20db05126',1,'stream.c']]],
  ['tds_5fstr_5fempty',['tds_str_empty',['../a00535.html#ga676fd3c5c489584d09c89d66c7a0af2d',1,'tds_str_empty():&#160;tdsstring.c'],['../a00535.html#ga676fd3c5c489584d09c89d66c7a0af2d',1,'tds_str_empty():&#160;tdsstring.c']]],
  ['tds_5fstrftime',['tds_strftime',['../a00530.html#ga8c9652e8b1f3e56a3289fd71b12cee1d',1,'tds_strftime(char *buf, size_t maxsize, const char *format, const TDSDATEREC *dr, int prec):&#160;convert.c'],['../a00530.html#ga8c9652e8b1f3e56a3289fd71b12cee1d',1,'tds_strftime(char *buf, size_t maxsize, const char *format, const TDSDATEREC *timeptr, int prec):&#160;convert.c']]],
  ['tds_5fstrndup',['tds_strndup',['../a00434.html#a1275e23db464803292b4c759c46621a6',1,'util.c']]],
  ['tds_5fsubmit_5fbegin_5ftran',['tds_submit_begin_tran',['../a00533.html#ga7bf3670d3d6dabed469b9eb117298079',1,'tds_submit_begin_tran(TDSSOCKET *tds):&#160;query.c'],['../a00533.html#ga7bf3670d3d6dabed469b9eb117298079',1,'tds_submit_begin_tran(TDSSOCKET *tds):&#160;query.c']]],
  ['tds_5fsubmit_5fcommit',['tds_submit_commit',['../a00533.html#ga530538c4c975524cf0b771a550fc94a3',1,'tds_submit_commit(TDSSOCKET *tds, int cont):&#160;query.c'],['../a00533.html#ga530538c4c975524cf0b771a550fc94a3',1,'tds_submit_commit(TDSSOCKET *tds, int cont):&#160;query.c']]],
  ['tds_5fsubmit_5fexecdirect',['tds_submit_execdirect',['../a00533.html#gae603aed795a4c5bb26ab159a11256996',1,'tds_submit_execdirect(TDSSOCKET *tds, const char *query, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c'],['../a00533.html#gae603aed795a4c5bb26ab159a11256996',1,'tds_submit_execdirect(TDSSOCKET *tds, const char *query, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c']]],
  ['tds_5fsubmit_5fexecute',['tds_submit_execute',['../a00533.html#ga3e7b4793c6f799fbc6c174f673bb5b32',1,'tds_submit_execute(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c'],['../a00533.html#ga3e7b4793c6f799fbc6c174f673bb5b32',1,'tds_submit_execute(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fsubmit_5foptioncmd',['tds_submit_optioncmd',['../a00533.html#gaf0da49585d39e99780a004ee2ca23479',1,'tds_submit_optioncmd(TDSSOCKET *tds, TDS_OPTION_CMD command, TDS_OPTION option, TDS_OPTION_ARG *param, TDS_INT param_size):&#160;query.c'],['../a00533.html#gaf0da49585d39e99780a004ee2ca23479',1,'tds_submit_optioncmd(TDSSOCKET *tds, TDS_OPTION_CMD command, TDS_OPTION option, TDS_OPTION_ARG *param, TDS_INT param_size):&#160;query.c']]],
  ['tds_5fsubmit_5fprepare',['tds_submit_prepare',['../a00533.html#ga74eb08c3a1c85be8ac9db428842c8b9d',1,'tds_submit_prepare(TDSSOCKET *tds, const char *query, const char *id, TDSDYNAMIC **dyn_out, TDSPARAMINFO *params):&#160;query.c'],['../a00533.html#ga74eb08c3a1c85be8ac9db428842c8b9d',1,'tds_submit_prepare(TDSSOCKET *tds, const char *query, const char *id, TDSDYNAMIC **dyn_out, TDSPARAMINFO *params):&#160;query.c']]],
  ['tds_5fsubmit_5fquery',['tds_submit_query',['../a00533.html#ga5a29ae7f99d089dc3cea85ec6ee5f3ab',1,'tds_submit_query(TDSSOCKET *tds, const char *query):&#160;query.c'],['../a00533.html#ga5a29ae7f99d089dc3cea85ec6ee5f3ab',1,'tds_submit_query(TDSSOCKET *tds, const char *query):&#160;query.c']]],
  ['tds_5fsubmit_5fquery_5fparams',['tds_submit_query_params',['../a00533.html#ga95e0fccedc459a4404f496eec74a369a',1,'tds_submit_query_params(TDSSOCKET *tds, const char *query, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c'],['../a00533.html#ga95e0fccedc459a4404f496eec74a369a',1,'tds_submit_query_params(TDSSOCKET *tds, const char *query, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c']]],
  ['tds_5fsubmit_5fqueryf',['tds_submit_queryf',['../a00533.html#gad695defcbf663b0023851a198206a772',1,'tds_submit_queryf(TDSSOCKET *tds, const char *queryf,...):&#160;query.c'],['../a00533.html#gad695defcbf663b0023851a198206a772',1,'tds_submit_queryf(TDSSOCKET *tds, const char *queryf,...):&#160;query.c']]],
  ['tds_5fsubmit_5frollback',['tds_submit_rollback',['../a00533.html#ga9c1cdcc388506a2ca3c0aaee8c461ba6',1,'tds_submit_rollback(TDSSOCKET *tds, int cont):&#160;query.c'],['../a00533.html#ga9c1cdcc388506a2ca3c0aaee8c461ba6',1,'tds_submit_rollback(TDSSOCKET *tds, int cont):&#160;query.c']]],
  ['tds_5fsubmit_5frpc',['tds_submit_rpc',['../a00533.html#ga5f071b94ad7889690762dc85646c74ab',1,'tds_submit_rpc(TDSSOCKET *tds, const char *rpc_name, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c'],['../a00533.html#ga5f071b94ad7889690762dc85646c74ab',1,'tds_submit_rpc(TDSSOCKET *tds, const char *rpc_name, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c']]],
  ['tds_5fsubmit_5funprepare',['tds_submit_unprepare',['../a00533.html#gaf573d8d4d2660c8c27770573fca05ff5',1,'tds_submit_unprepare(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c'],['../a00533.html#gaf573d8d4d2660c8c27770573fca05ff5',1,'tds_submit_unprepare(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fswap_5fnumeric',['tds_swap_numeric',['../a00260.html#aa818c1cbf4d16e609b7e4895cc7ed74f',1,'data.c']]],
  ['tds_5fsyb_5fver',['TDS_SYB_VER',['../a00434.html#aca53a637849948c4b7a07f69e40c685c',1,'tds.h']]],
  ['tds_5fsybase_5fdbdaterec',['tds_sybase_dbdaterec',['../a01289.html',1,'']]],
  ['tds_5fsybase_5fdbdaterec2',['tds_sybase_dbdaterec2',['../a01297.html',1,'']]],
  ['tds_5fsys_5ficonv_5fopen',['tds_sys_iconv_open',['../a00531.html#ga900b0bce08c6bfc2e7c988f4b5970516',1,'tds_sys_iconv_open(const char *tocode, const char *fromcode):&#160;iconv.c'],['../a00531.html#ga900b0bce08c6bfc2e7c988f4b5970516',1,'tds_sys_iconv_open(const char *tocode, const char *fromcode):&#160;iconv.c']]],
  ['tds_5fthread',['tds_thread',['../a01209.html',1,'']]],
  ['tds_5ftime',['tds_time',['../a00717.html',1,'']]],
  ['tds_5ftimestamp_5fstr',['tds_timestamp_str',['../a00434.html#a9222a29979fcf3a660f9f4ca3cc494ee',1,'threadsafe.c']]],
  ['tds_5ftoken_5fname',['tds_token_name',['../a00536.html#ga7f24a7af985cd320788122e98072b7af',1,'token.c']]],
  ['tds_5funget_5fbyte',['tds_unget_byte',['../a00534.html#gad70d59fb317d098b0c9fd29dd77131a8',1,'tds_unget_byte(TDSSOCKET *tds):&#160;read.c'],['../a00534.html#gad70d59fb317d098b0c9fd29dd77131a8',1,'tds_unget_byte(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fupd_5fcol',['tds_upd_col',['../a01149.html',1,'']]],
  ['tds_5fvariant',['tds_variant',['../a01117.html',1,'']]],
  ['tds_5fvarmax_5fstream',['tds_varmax_stream',['../a00721.html',1,'']]],
  ['tds_5fversion',['tds_version',['../a01101.html#a8f9f756b25fd18916a6080f9c22f835d',1,'tds_login']]],
  ['tds_5fwillconvert',['tds_willconvert',['../a00530.html#ga80487b313213f60d8be71a50a002bb2c',1,'tds_willconvert(int srctype, int desttype):&#160;convert.c'],['../a00530.html#ga80487b313213f60d8be71a50a002bb2c',1,'tds_willconvert(int srctype, int desttype):&#160;convert.c']]],
  ['tds_5fwrite_5fdump',['tds_write_dump',['../a00434.html#a4766b1a553077cb3257d36b9ac28f5b5',1,'log.c']]],
  ['tds_5fwritetext_5fcontinue',['tds_writetext_continue',['../a00248.html#ab68dead99a2ebec55895a10cd3db5202',1,'tds_writetext_continue(TDSSOCKET *tds, const TDS_UCHAR *text, TDS_UINT size):&#160;bulk.c'],['../a00434.html#ab68dead99a2ebec55895a10cd3db5202',1,'tds_writetext_continue(TDSSOCKET *tds, const TDS_UCHAR *text, TDS_UINT size):&#160;bulk.c']]],
  ['tds_5fwritetext_5fend',['tds_writetext_end',['../a00248.html#ac1e460551f1188620ea478238864ac4b',1,'tds_writetext_end(TDSSOCKET *tds):&#160;bulk.c'],['../a00434.html#ac1e460551f1188620ea478238864ac4b',1,'tds_writetext_end(TDSSOCKET *tds):&#160;bulk.c']]],
  ['tds_5fwritetext_5fstart',['tds_writetext_start',['../a00248.html#a7711612cc544a7da2c7aa212b870acb2',1,'tds_writetext_start(TDSSOCKET *tds, const char *objname, const char *textptr, const char *timestamp, int with_log, TDS_UINT size):&#160;bulk.c'],['../a00434.html#a7711612cc544a7da2c7aa212b870acb2',1,'tds_writetext_start(TDSSOCKET *tds, const char *objname, const char *textptr, const char *timestamp, int with_log, TDS_UINT size):&#160;bulk.c']]],
  ['tds_5fwriting',['TDS_WRITING',['../a00434.html#a87cdae58f91ebe9229206bf0628f8e33a4a4fcc1840bee1e09521f08a0184d025',1,'tds.h']]],
  ['tdsblob',['TDSBLOB',['../a00434.html#a479425fecfdcd8e617b2b2e38d54b664',1,'tds.h']]],
  ['tdscursor',['TDSCURSOR',['../a00434.html#aad3739704ca49d8ebe445ca9b5e3b8b2',1,'tds.h']]],
  ['tdsdaterec',['tdsdaterec',['../a01081.html',1,'tdsdaterec'],['../a00434.html#a2ab81f7a472558595c985c9c3f8c528e',1,'TDSDATEREC():&#160;tds.h']]],
  ['tdsdatetime',['tdsdatetime',['../a01021.html',1,'']]],
  ['tdsdatetime4',['tdsdatetime4',['../a01025.html',1,'']]],
  ['tdsdbopen',['tdsdbopen',['../a00524.html#ga2c99ec565452279e9a382451d89642eb',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c'],['../a00524.html#ga2c99ec565452279e9a382451d89642eb',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c']]],
  ['tdsdump_5fclose',['tdsdump_close',['../a00434.html#a2f00fc0907d3bb04ce0eeb9738e08d0c',1,'log.c']]],
  ['tdsdump_5fcol',['tdsdump_col',['../a00434.html#aaee3fe5c514ce5570c9548de9b16e0d9',1,'log.c']]],
  ['tdsdump_5fdump_5fbuf',['tdsdump_dump_buf',['../a00434.html#a79449d2f35a8acc8ed0585044f75524d',1,'log.c']]],
  ['tdsdump_5flog',['tdsdump_log',['../a00434.html#ab45c291105027e69836002e1dd586141',1,'log.c']]],
  ['tdsdump_5foff',['tdsdump_off',['../a00434.html#ac4dfaa4426d8a98bb1c74e46293eb4d1',1,'log.c']]],
  ['tdsdump_5fon',['tdsdump_on',['../a00434.html#a0bff83b40604dcc2e5d4f6f26256a96d',1,'log.c']]],
  ['tdsdump_5fopen',['tdsdump_open',['../a00434.html#a24471508ddfde7cc0f8577801e70c42f',1,'log.c']]],
  ['tdsdynamic',['TDSDYNAMIC',['../a00434.html#a4a7511ca7305098f5bb111aa9214810b',1,'tds.h']]],
  ['tdsenv',['TDSENV',['../a00434.html#ab2c3d86ac695df335c70b088729853ae',1,'tds.h']]],
  ['tdserror',['tdserror',['../a00434.html#abf18b98efef6ce2dc0b97d658a3a1918',1,'util.c']]],
  ['tdsfilestream',['TDSFILESTREAM',['../a00248.html#a017b2e89d0641a6af2a84e3953574fb0',1,'bulk.c']]],
  ['tdsiconvdir',['tdsiconvdir',['../a00941.html',1,'']]],
  ['tdsiconvinfo',['tdsiconvinfo',['../a00945.html',1,'']]],
  ['tdsmoney',['tdsmoney',['../a01013.html',1,'']]],
  ['tdsmoney4',['tdsmoney4',['../a01017.html',1,'']]],
  ['tdsnumeric',['tdsnumeric',['../a01005.html',1,'']]],
  ['tdsoldmoney',['tdsoldmoney',['../a01009.html',1,'']]],
  ['tdspbcb',['TDSPBCB',['../a00248.html#a786e761d5de7ac54bff4a948e1dab4b6',1,'bulk.c']]],
  ['tdsresultinfo',['TDSRESULTINFO',['../a00434.html#a22c989e4b40c76c0bfb64c6610f4a8b6',1,'tds.h']]],
  ['tdsunique',['tdsunique',['../a01029.html',1,'']]],
  ['tdsvariant',['TDSVARIANT',['../a00434.html#a7ef9511424cb9015043fa7e7da4efb74',1,'tds.h']]],
  ['tdsvername_5ft',['tdsvername_t',['../a00713.html',1,'']]],
  ['term_5flen',['term_len',['../a00693.html#aae893302d33ee1e9d83c3d85d7390dca',1,'tds_file_stream']]],
  ['terminator',['terminator',['../a00693.html#a463c28a7d862c0a6d7bf3170dd614dc0',1,'tds_file_stream']]],
  ['time',['time',['../a01077.html#afd6a58ec251f2c08a040917ba5a8cd3f',1,'TDS_DATETIMEALL::time()'],['../a01265.html#a6bb5dcd5b47813b71934546e0c60e035',1,'DBDATETIMEALL::time()']]],
  ['timezone',['timezone',['../a01081.html#a624e21e65d0ae89797b3a7eadc48829f',1,'tdsdaterec']]],
  ['tm_5fhour',['tm_hour',['../a00717.html#a6ece03e77f69035da83d5739e16ef905',1,'tds_time']]],
  ['tm_5fmday',['tm_mday',['../a00717.html#a8dfc26d484c247040f521f20288651f1',1,'tds_time']]],
  ['tm_5fmin',['tm_min',['../a00717.html#ab50f30e05dc6b493d347918ab7ded1e9',1,'tds_time']]],
  ['tm_5fmon',['tm_mon',['../a00717.html#adce28126e9bbd4ef005e3bf181d59745',1,'tds_time']]],
  ['tm_5fns',['tm_ns',['../a00717.html#a386f1cfcabbe3ed86afe72bed75778cf',1,'tds_time']]],
  ['tm_5fsec',['tm_sec',['../a00717.html#adeb5e3f535662c0341d28f8d669cb59b',1,'tds_time']]],
  ['tm_5fyear',['tm_year',['../a00717.html#a3e27d50ebb5196356a6a8a9b495c8758',1,'tds_time']]],
  ['tmp_5fcol_5fstruct',['tmp_col_struct',['../a00673.html',1,'']]],
  ['todo_20list',['Todo List',['../a00515.html',1,'']]],
  ['token_2ec',['token.c',['../a00344.html',1,'']]],
  ['type',['type',['../a01157.html#a889aafdde1d57c9be0585326022831f0',1,'tds_cursor']]]
];
